==> cidentd-0.2.1.pre2.tar.gz: cidentd-0.2.1.pre2/src/bits/strtotype/strtoUseridType.c <==
/***************************************************************************
 *   Copyright (C) 2004 by Trevor "beltorak" Torrez                        *
 *   beltorak@phreaker.net                                                 *
 *   strtoUseridType.c part of cidentd version 0.2                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <sys/types.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>

#include "strtotype.h"

#include <macros.h>
#include <logutils.h>

/* Translates a string to its userid type */
int
strtoUseridType( c_userid_t* ut, char* userid ) {
	if( is_nil(userid) ) {
        	carp("Attempted to pass nothing as the userid");
                return -1;
        }

        if( strcmp(userid, "name") == 0 )
        	*ut = UT_NAME;
        else if( strcmp(userid, "number") == 0 )
        	*ut = UT_UID;
        else if( strncmp(userid, "literal=", strlen("literal=")) == 0 )
        	*ut = UT_LITERAL;
        else {
        	carp("Invalid userid type \"%s\"", userid);
                return -1;
        }

        return 0;
} /* -- end strtouseridtype() -- */


/* -- end strtoUseridType.c -- */

==> cidentd-0.2.2.tar.gz: cidentd-0.2.2/src/bits/strtotype/strtoUseridType.c <==
/***************************************************************************
 *   Copyright (C) 2004 by Trevor "beltorak" Torrez                        *
 *   beltorak@phreaker.net                                                 *
 *   strtoUseridType.c part of cidentd version 0.2                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <sys/types.h>
#include <unistd.h>
#include <errno.h>

#include "strtotype.h"

#include <xmalloc.h>
#include <xstring.h>
#include <logutils.h>

/* Translates a string to its userid type */
int
strtoUseridType( c_userid_t* ut, char* userid ) {
	if( xstr_is_nil(userid) ) {
        	carp("Attempted to pass nothing as the userid");
                return -1;
        }

        if( xstr_is_equal(userid, "name") )
        	*ut = UT_NAME;
        else if( xstr_is_equal(userid, "number") )
        	*ut = UT_UID;
        else if( xstr_has_prefix(userid, "literal=") )
        	*ut = UT_LITERAL;
        else {
        	carp("Invalid userid type \"%s\"", userid);
                return -1;
        }

        return 0;
} /* -- end strtouseridtype() -- */


/* -- end strtoUseridType.c -- */
